<img style="float: right;" width="120px" src="images/MiniclipLogo.jpg"/>

# MCGoliath

MCGoliath is a module that allows applications written in C++ to interact with Miniclip's Goliath server.

## Goliath Events

This Goliath Events API was generated for the game **`8ballpool_mobile`**.

### MCGoliath Initialization

MCGoliath must be initialized with the API Key and the HMAC Key (Shared Secret). The API Key and HMAC Key are different for each one of the environments available for the game: development, staging, and production:

* Development
    * API Key: `38e0475f-9986-4940-a683-813bd4d9a5bd`
    * HMAC Key: `8f7bd4c3-6b2f-11e9-b312-06a2aa13cf6c`
* Staging
    * API Key: `f43cfa55-eda5-4e98-a847-21c701539afe`
    * HMAC Key: `8f7bd03a-6b2f-11e9-b312-06a2aa13cf6c`
* Production
    * API Key: `8321af99-556f-4254-9429-76432e458728`
    * HMAC Key: `8f7bc9d4-6b2f-11e9-b312-06a2aa13cf6c`

The code snippet below is an example on how to initialize MCGoliath for **`8ballpool_mobile`** using the development environment:

```cpp
// API Key and Shared Secret for the development environment.
const std::string apiKey       = "38e0475f-9986-4940-a683-813bd4d9a5bd";
const std::string sharedSecret = "8f7bd4c3-6b2f-11e9-b312-06a2aa13cf6c";

// Initialize MCGoliath.
MCGoliathWrapper::initialize(apiKey, sharedSecret);
```

Before queueing events, it's necessary to set the user and session ids using their corresponding methods of the module:

```cpp
MCGoliathWrapper& goliath = MCGoliathWrapper::sharedGoliath();

goliath.setUserID("the user id");
goliath.setSessionID("the session id");
```

The user and the session ids can be changed anytime if necessary using the methods above.

After initialization the module can be used to queue events to the Goliath server. To queue events use the classes documented in the Goliath Events section below.

### Public API

The Goliath events API provide an easy interface to send events over to Goliath, allowing the developer to build the events, fill-in their fields, and post them when they're ready, without having to assemble a valid JSON object for each event.

Each event has properties that the developer can set, and a `queue` method that will send it to the Goliath server using MCGoliath. Before the event is sent, some fields will be filled automatically, it will be validated and messages will be logged with the problems that are found, i.e. required fields that haven't been set, and values too big to fit the allowed space on the server. These problems do not prevent the event from being sent.

All these Goliath Events exist inside the `mc::goliath::events` namespace, and are provided int the `GoliathEvents.hpp` and `GoliathEvents.cpp` files which must be added to your project to be compiled along with your game.

Each event has a corresponding class in the `mc::goliath::events` namespace.

To send an event, create an instance of the appropriated class, and set its properties to the appropriate values. Some properties are required, failure to set them will generate a log message but will *not* prevent the event from being sent to the Goliath server. Likewise, some properties have a maximum size, if that size is exceeded a log message is generated but it will *not* prevent the event from being sent.

When the event instance is populated, call its `queue()` method to queue it for sending.

#### **AddFriend** event


```cpp
class AddFriend {
public:
    void setFriendId(const std::string& value);
    void setSuggested(const bool& value);

    // Queues the event to be sent to the Goliath server.
    void queue();
}
```

##### FriendId field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Required

##### Suggested field


Details:

* Type `bool`
* Required

#### **AllowNotifications** event


```cpp
class AllowNotifications {
public:
    void setStep(const std::string& value);

    // Queues the event to be sent to the Goliath server.
    void queue();
}
```

##### Step field


Details:

* Type `std::string`
* Maximum size is 50 characters.
* Required

#### **ChallengeDropDown** event


```cpp
class ChallengeDropDown {
public:
    void setAction(const std::string& value);
    void setFriendId(const std::string& value);
    void setFriendType(const std::vector<mc::Value>& value);
    void setInGame(const bool& value);
    void setStep(const std::string& value);
    void setType(const std::string& value);

    // Queues the event to be sent to the Goliath server.
    void queue();
}
```

##### Action field


Details:

* Type `std::string`
* Maximum size is 50 characters.
* Optional

##### FriendId field


Details:

* Type `std::string`
* Maximum size is 50 characters.
* Required

##### FriendType field


Details:

* Type `std::vector<mc::Value>`
* Required

##### InGame field


Details:

* Type `bool`
* Optional

##### Step field


Details:

* Type `std::string`
* Maximum size is 50 characters.
* Required

##### Type field


Details:

* Type `std::string`
* Maximum size is 50 characters.
* Required

#### **ClientInit** event


```cpp
class ClientInit {
public:
    void setAuthenticatedAccounts(const std::vector<mc::Value>& value);
    void setDeviceCompromised(const bool& value);
    void setFacebookId(const std::string& value);
    void setFacebookIdForBusiness(const std::string& value);
    void setGoogleGamerId(const std::string& value);
    void setGooglePlusId(const std::string& value);
    void setInstalledApps(const std::vector<mc::Value>& value);
    void setMiniclipId(const std::string& value);
    void setNotificationsEnabled(const bool& value);
    void setPushToken(const std::string& value);

    // Queues the event to be sent to the Goliath server.
    void queue();
}
```

##### AuthenticatedAccounts field

An array with strings identifying the accounts the user has authenticated at the start of that session.	

Details:

* Type `std::vector<mc::Value>`
* Optional

##### DeviceCompromised field


Details:

* Type `bool`
* Optional

##### FacebookId field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

##### FacebookIdForBusiness field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

##### GoogleGamerId field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

##### GooglePlusId field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

##### InstalledApps field

The list of Miniclips apps installed in the device (subset of a pre-defined check list).

Details:

* Type `std::vector<mc::Value>`
* Optional

##### MiniclipId field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

##### NotificationsEnabled field


Details:

* Type `bool`
* Optional

##### PushToken field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

#### **ClubGifts** event


```cpp
class ClubGifts {
public:
    void setClubId(const std::string& value);
    void setStep(const std::string& value);

    // Queues the event to be sent to the Goliath server.
    void queue();
}
```

##### ClubId field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Required

##### Step field


Details:

* Type `std::string`
* Maximum size is 50 characters.
* Required

#### **ClubMessages** event


```cpp
class ClubMessages {
public:
    void setClubId(const std::string& value);
    void setMessages(const long& value);
    void setMessageSession(const std::string& value);

    // Queues the event to be sent to the Goliath server.
    void queue();
}
```

##### ClubId field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Required

##### Messages field


Details:

* Type `long`
* Required

##### MessageSession field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

#### **ConfigUpdate** event


```cpp
class ConfigUpdate {
public:
    void setConfigLatestVersion(const std::string& value);
    void setConfigOldVersion(const std::string& value);

    // Queues the event to be sent to the Goliath server.
    void queue();
}
```

##### ConfigLatestVersion field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Required

##### ConfigOldVersion field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

#### **CueRecharge** event

When a cue is recharged.

```cpp
class CueRecharge {
public:
    void setCueTag(const std::string& value);
    void setRechargeCost(const int& value);
    void setRechargeType(const std::string& value);

    // Queues the event to be sent to the Goliath server.
    void queue();
}
```

##### CueTag field

The tag identifying the cue

Details:

* Type `std::string`
* Maximum size is 256 characters.
* Required

##### RechargeCost field


Details:

* Type `int`
* Required

##### RechargeType field


Details:

* Type `std::string`
* Maximum size is 50 characters.
* Required

#### **FailedPurchase** event


```cpp
class FailedPurchase {
public:
    void setProductId(const std::string& value);
    void setResponse(const std::string& value);

    // Queues the event to be sent to the Goliath server.
    void queue();
}
```

##### ProductId field

The SKU of the in-app

Details:

* Type `std::string`
* Maximum size is 256 characters.
* Required

##### Response field


Details:

* Type `std::string`
* Maximum size is 5000 characters.
* Required

#### **FtueFunnel** event


```cpp
class FtueFunnel {
public:
    void setStep(const std::string& value);

    // Queues the event to be sent to the Goliath server.
    void queue();
}
```

##### Step field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Required

#### **GiftAction** event


```cpp
class GiftAction {
public:
    void setCountFriend(const int& value);
    void setCountPrevInbox(const int& value);
    void setCountPrevInboxSuggestedPlayer(const int& value);
    void setCountSuggestedPlayer(const int& value);
    void setGiftAction(const std::string& value);
    void setPlacement(const std::string& value);
    void setTotalCoins(const int& value);

    // Queues the event to be sent to the Goliath server.
    void queue();
}
```

##### CountFriend field


Details:

* Type `int`
* Optional

##### CountPrevInbox field


Details:

* Type `int`
* Required

##### CountPrevInboxSuggestedPlayer field


Details:

* Type `int`
* Required

##### CountSuggestedPlayer field


Details:

* Type `int`
* Optional

##### GiftAction field


Details:

* Type `std::string`
* Maximum size is 50 characters.
* Required

##### Placement field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Required

##### TotalCoins field


Details:

* Type `int`
* Optional

#### **Hilo** event


```cpp
class Hilo {
public:
    void setCashContinue(const long& value);
    void setCashEntry(const int& value);
    void setCoinsWon(const long& value);

    // Queues the event to be sent to the Goliath server.
    void queue();
}
```

##### CashContinue field


Details:

* Type `long`
* Optional

##### CashEntry field


Details:

* Type `int`
* Required

##### CoinsWon field


Details:

* Type `long`
* Required

#### **InterstitialBannerFunnel** event


```cpp
class InterstitialBannerFunnel {
public:
    void setAdUnitId(const std::string& value);
    void setFailureReason(const std::string& value);
    void setIntentionalClick(const bool& value);
    void setMediator(const std::string& value);
    void setNetwork(const std::string& value);
    void setPlacementName(const std::string& value);
    void setRequestId(const std::string& value);
    void setStep(const std::string& value);
    void setTechVersion(const std::string& value);
    void setType(const std::string& value);

    // Queues the event to be sent to the Goliath server.
    void queue();
}
```

##### AdUnitId field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

##### FailureReason field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

##### IntentionalClick field

Undefined

Details:

* Type `bool`
* Optional

##### Mediator field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Required

##### Network field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

##### PlacementName field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

##### RequestId field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Required

##### Step field


Details:

* Type `std::string`
* Maximum size is 50 characters.
* Required

##### TechVersion field

Undefined

Details:

* Type `std::string`
* Maximum size is 50 characters.
* Required

##### Type field


Details:

* Type `std::string`
* Maximum size is 50 characters.
* Required

#### **LaStreak** event


```cpp
class LaStreak {
public:
    void setAction(const std::string& value);
    void setCashPaid(const int& value);
    void setCashPaidContext(const std::string& value);
    void setStreakCount(const int& value);

    // Queues the event to be sent to the Goliath server.
    void queue();
}
```

##### Action field


Details:

* Type `std::string`
* Maximum size is 50 characters.
* Required

##### CashPaid field


Details:

* Type `int`
* Required

##### CashPaidContext field


Details:

* Type `std::string`
* Maximum size is 50 characters.
* Required

##### StreakCount field


Details:

* Type `int`
* Required

#### **LocalNotificationSchedule** event


```cpp
class LocalNotificationSchedule {
public:
    void setNotificationId(const std::string& value);
    void setSecondsPrior(const long& value);

    // Queues the event to be sent to the Goliath server.
    void queue();
}
```

##### NotificationId field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Required

##### SecondsPrior field


Details:

* Type `long`
* Required

#### **LuckyShotInteraction** event

Undefined

```cpp
class LuckyShotInteraction {
public:
    void setClicks(const std::string& value);
    void setEntryType(const std::string& value);
    void setPlay(const bool& value);
    void setStep(const std::string& value);

    // Queues the event to be sent to the Goliath server.
    void queue();
}
```

##### Clicks field

Undefined

Details:

* Type `std::string`
* Maximum size is 50 characters.
* Optional

##### EntryType field

Undefined

Details:

* Type `std::string`
* Maximum size is 50 characters.
* Optional

##### Play field

Undefined

Details:

* Type `bool`
* Optional

##### Step field

Undefined

Details:

* Type `std::string`
* Maximum size is 50 characters.
* Required

#### **MatchChat** event

At the start of a session, whenever is possible to get that information from client

```cpp
class MatchChat {
public:
    void setMatchId(const std::string& value);
    void setMessageType(const std::string& value);
    void setOpponentId(const std::string& value);
    void setOpponentMuted(const std::string& value);
    void setProductId(const std::string& value);

    // Queues the event to be sent to the Goliath server.
    void queue();
}
```

##### MatchId field

	A unique id for each match.

Details:

* Type `std::string`
* Maximum size is 256 characters.
* Required

##### MessageType field

The type of the message being sent. It can be 'emote', 'animated_emote' or 'text_message'

Details:

* Type `std::string`
* Maximum size is 50 characters.
* Required

##### OpponentId field

The user ID of the opponent. The user ID of the other player is included in the global parameters.

Details:

* Type `std::string`
* Maximum size is 256 characters.
* Required

##### OpponentMuted field

'direct' when the user had muted the opponent directly; 
'global' when the user has global muted option turned on; 
'not_muted' when the user saw the message the opponent sent

Details:

* Type `std::string`
* Maximum size is 10 characters.
* Required

##### ProductId field

The product id of the message being sent. When message_type is emote or animated_emote send its product id, and when message_type is text_message send the chat_pack_id.

Details:

* Type `std::string`
* Maximum size is 256 characters.
* Required

#### **MatchDecal** event

At the end of a match, or whenever is possible to get that information from client afterwards 

```cpp
class MatchDecal {
public:
    void setDecalId(const std::string& value);
    void setDisableDecal(const bool& value);
    void setMatchId(const std::string& value);

    // Queues the event to be sent to the Goliath server.
    void queue();
}
```

##### DecalId field

The id of the decal being used.

Details:

* Type `std::string`
* Maximum size is 256 characters.
* Required

##### DisableDecal field

True if the decals are disable; False if the decals are not disable

Details:

* Type `bool`
* Required

##### MatchId field

A unique id for each match.

Details:

* Type `std::string`
* Maximum size is 256 characters.
* Required

#### **MissionsMenu** event

When a user enters the daily missions menu

```cpp
class MissionsMenu {
public:
    void setEntryPoint(const std::string& value);

    // Queues the event to be sent to the Goliath server.
    void queue();
}
```

##### EntryPoint field

	The entry point where the user enters enter the daily missions menu. It can be: 'main_menu' or 'pool_pass_landing_page'

Details:

* Type `std::string`
* Maximum size is 50 characters.
* Required

#### **OfferWall** event


```cpp
class OfferWall {
public:
    void setCurrency(const std::string& value);
    void setPlacement(const std::string& value);
    void setProvider(const std::string& value);

    // Queues the event to be sent to the Goliath server.
    void queue();
}
```

##### Currency field


Details:

* Type `std::string`
* Maximum size is 50 characters.
* Required

##### Placement field


Details:

* Type `std::string`
* Maximum size is 50 characters.
* Required

##### Provider field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Required

#### **OfferwallFunnel** event


```cpp
class OfferwallFunnel {
public:
    void setFailureReason(const std::string& value);
    void setMediator(const std::string& value);
    void setNetwork(const std::string& value);
    void setRequestId(const std::string& value);
    void setRewardAmount(const long& value);
    void setRewardProduct(const std::string& value);
    void setStep(const std::string& value);
    void setTechVersion(const std::string& value);

    // Queues the event to be sent to the Goliath server.
    void queue();
}
```

##### FailureReason field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

##### Mediator field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Required

##### Network field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

##### RequestId field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Required

##### RewardAmount field


Details:

* Type `long`
* Optional

##### RewardProduct field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

##### Step field


Details:

* Type `std::string`
* Maximum size is 50 characters.
* Required

##### TechVersion field

Undefined

Details:

* Type `std::string`
* Maximum size is 50 characters.
* Required

#### **PoolPassInteraction** event

When the user enters the Loading page of the Pool Pass or reached the Premium Pass Purchase Menu

```cpp
class PoolPassInteraction {
public:
    void setEntryPoint(const std::string& value);
    void setSeasonId(const std::string& value);
    void setStep(const std::string& value);

    // Queues the event to be sent to the Goliath server.
    void queue();
}
```

##### EntryPoint field

The name of the button a user has to click in order to go to the menus defined in "step". For example ‘VictoryBoxesAcceleration’, ‘ClaimBattlePassPrize’, ‘BattlePassLogo’, 'MainMenu', ... Reports null when its a pop-up that appear automatically (season_start).

Details:

* Type `std::string`
* Maximum size is 50 characters.
* Optional

##### SeasonId field

The unique identifier of the season.

Details:

* Type `std::string`
* Maximum size is 256 characters.
* Required

##### Step field

'season_progression': when user clicks in the pool pass button from the main menu, to enter pool pass landing page.
'premium': when user clicks in the battle pass logo in the pool pass landing page

Details:

* Type `std::string`
* Maximum size is 50 characters.
* Optional

#### **PrivacyPolicyConsent** event


```cpp
class PrivacyPolicyConsent {
public:
    void setClickResult(const std::string& value);
    void setContext(const std::string& value);
    void setStep(const std::string& value);

    // Queues the event to be sent to the Goliath server.
    void queue();
}
```

##### ClickResult field


Details:

* Type `std::string`
* Maximum size is 50 characters.
* Optional

##### Context field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Required

##### Step field


Details:

* Type `std::string`
* Maximum size is 50 characters.
* Required

#### **PromoBadgeInteraction** event


```cpp
class PromoBadgeInteraction {
public:
    void setCampaignId(const std::string& value);
    void setGroupId(const std::string& value);
    void setPromoId(const std::string& value);
    void setStep(const std::string& value);
    void setSystemId(const std::string& value);

    // Queues the event to be sent to the Goliath server.
    void queue();
}
```

##### CampaignId field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Required

##### GroupId field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Required

##### PromoId field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Required

##### Step field


Details:

* Type `std::string`
* Maximum size is 50 characters.
* Required

##### SystemId field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Required

#### **PromoExtrabuttonClick** event

Click table for lobby buttons 

```cpp
class PromoExtrabuttonClick {
public:
    void setActionId(const std::string& value);
    void setActionTarget(const std::string& value);
    void setActionType(const std::string& value);
    void setCampaignId(const std::string& value);
    void setGroupId(const std::string& value);
    void setPopupGeneration(const std::string& value);
    void setPopupInteraction(const std::string& value);
    void setPromoId(const std::string& value);

    // Queues the event to be sent to the Goliath server.
    void queue();
}
```

##### ActionId field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

##### ActionTarget field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

##### ActionType field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

##### CampaignId field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

##### GroupId field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

##### PopupGeneration field


Details:

* Type `std::string`
* Maximum size is 50 characters.
* Required

##### PopupInteraction field


Details:

* Type `std::string`
* Maximum size is 50 characters.
* Required

##### PromoId field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Required

#### **PromoInterstitialClick** event

Click table for interstitial popup

```cpp
class PromoInterstitialClick {
public:
    void setActionId(const std::string& value);
    void setActionTarget(const std::string& value);
    void setActionType(const std::string& value);
    void setCampaignId(const std::string& value);
    void setGroupId(const std::string& value);
    void setPopupGeneration(const std::string& value);
    void setPopupInteraction(const std::string& value);
    void setPromoId(const std::string& value);

    // Queues the event to be sent to the Goliath server.
    void queue();
}
```

##### ActionId field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

##### ActionTarget field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

##### ActionType field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

##### CampaignId field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

##### GroupId field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

##### PopupGeneration field


Details:

* Type `std::string`
* Maximum size is 50 characters.
* Required

##### PopupInteraction field


Details:

* Type `std::string`
* Maximum size is 50 characters.
* Required

##### PromoId field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Required

#### **PromoInterstitialImpression** event

Impression table for interstitial popup

```cpp
class PromoInterstitialImpression {
public:
    void setCampaignId(const std::string& value);
    void setGroupId(const std::string& value);
    void setPopupGeneration(const std::string& value);
    void setPromoId(const std::string& value);

    // Queues the event to be sent to the Goliath server.
    void queue();
}
```

##### CampaignId field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

##### GroupId field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

##### PopupGeneration field


Details:

* Type `std::string`
* Maximum size is 50 characters.
* Required

##### PromoId field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Required

#### **PromoPromotionClick** event

Click table for promotion popup

```cpp
class PromoPromotionClick {
public:
    void setActionId(const std::string& value);
    void setActionTarget(const std::string& value);
    void setActionType(const std::string& value);
    void setCampaignId(const std::string& value);
    void setGroupId(const std::string& value);
    void setPopupGeneration(const std::string& value);
    void setPopupInteraction(const std::string& value);
    void setPromoId(const std::string& value);

    // Queues the event to be sent to the Goliath server.
    void queue();
}
```

##### ActionId field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

##### ActionTarget field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

##### ActionType field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

##### CampaignId field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

##### GroupId field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

##### PopupGeneration field


Details:

* Type `std::string`
* Maximum size is 50 characters.
* Required

##### PopupInteraction field


Details:

* Type `std::string`
* Maximum size is 50 characters.
* Required

##### PromoId field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Required

#### **PromoPromotionImpression** event

Impression table for promo popup

```cpp
class PromoPromotionImpression {
public:
    void setCampaignId(const std::string& value);
    void setGroupId(const std::string& value);
    void setPopupGeneration(const std::string& value);
    void setPromoId(const std::string& value);

    // Queues the event to be sent to the Goliath server.
    void queue();
}
```

##### CampaignId field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

##### GroupId field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

##### PopupGeneration field


Details:

* Type `std::string`
* Maximum size is 50 characters.
* Required

##### PromoId field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Required

#### **SendChallengeFriends** event


```cpp
class SendChallengeFriends {
public:
    void setEntryPoint(const std::string& value);
    void setFriendId(const std::string& value);
    void setFriendType(const std::vector<mc::Value>& value);
    void setInGame(const bool& value);

    // Queues the event to be sent to the Goliath server.
    void queue();
}
```

##### EntryPoint field


Details:

* Type `std::string`
* Maximum size is 50 characters.
* Required

##### FriendId field


Details:

* Type `std::string`
* Maximum size is 50 characters.
* Required

##### FriendType field


Details:

* Type `std::vector<mc::Value>`
* Required

##### InGame field


Details:

* Type `bool`
* Optional

#### **SendInvite** event


```cpp
class SendInvite {
public:
    void setNumInvites(const int& value);
    void setPlacement(const std::string& value);
    void setSocialNetwork(const std::string& value);

    // Queues the event to be sent to the Goliath server.
    void queue();
}
```

##### NumInvites field


Details:

* Type `int`
* Required

##### Placement field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Required

##### SocialNetwork field

Undefined

Details:

* Type `std::string`
* Maximum size is 50 characters.
* Required

#### **SocialActivityTab** event

Undefined

```cpp
class SocialActivityTab {
public:
    void setMessageType(const std::string& value);
    void setNMessages(const int& value);

    // Queues the event to be sent to the Goliath server.
    void queue();
}
```

##### MessageType field

Undefined

Details:

* Type `std::string`
* Maximum size is 50 characters.
* Required

##### NMessages field

Undefined

Details:

* Type `int`
* Required

#### **SurpriseBoxPurchaseContext** event


```cpp
class SurpriseBoxPurchaseContext {
public:
    void setBoxType(const std::string& value);
    void setContext(const std::string& value);
    void setTransactionId(const std::string& value);

    // Queues the event to be sent to the Goliath server.
    void queue();
}
```

##### BoxType field


Details:

* Type `std::string`
* Maximum size is 50 characters.
* Optional

##### Context field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Required

##### TransactionId field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Required

#### **VideoAdFunnel** event


```cpp
class VideoAdFunnel {
public:
    void setAdUnitId(const std::string& value);
    void setFailureReason(const std::string& value);
    void setIntentionalClick(const bool& value);
    void setMediator(const std::string& value);
    void setNetwork(const std::string& value);
    void setPlacementName(const std::string& value);
    void setRequestId(const std::string& value);
    void setRewardAmount(const long& value);
    void setRewardProduct(const std::string& value);
    void setStep(const std::string& value);
    void setTechVersion(const std::string& value);

    // Queues the event to be sent to the Goliath server.
    void queue();
}
```

##### AdUnitId field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

##### FailureReason field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

##### IntentionalClick field

Undefined

Details:

* Type `bool`
* Optional

##### Mediator field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Required

##### Network field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

##### PlacementName field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

##### RequestId field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Required

##### RewardAmount field


Details:

* Type `long`
* Optional

##### RewardProduct field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

##### Step field


Details:

* Type `std::string`
* Maximum size is 50 characters.
* Required

##### TechVersion field

Undefined

Details:

* Type `std::string`
* Maximum size is 50 characters.
* Required

#### **VideoAds** event


```cpp
class VideoAds {
public:
    void setButtonMenu(const std::string& value);
    void setConsecutiveCount(const long& value);
    void setPlacement(const std::string& value);
    void setPrizeAmount(const long& value);
    void setProgressiveReward(const int& value);
    void setStep(const std::string& value);
    void setVideoAdsTokenType(const std::string& value);

    // Queues the event to be sent to the Goliath server.
    void queue();
}
```

##### ButtonMenu field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Optional

##### ConsecutiveCount field


Details:

* Type `long`
* Required

##### Placement field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Required

##### PrizeAmount field


Details:

* Type `long`
* Optional

##### ProgressiveReward field


Details:

* Type `int`
* Optional

##### Step field


Details:

* Type `std::string`
* Maximum size is 256 characters.
* Required

##### VideoAdsTokenType field


Details:

* Type `std::string`
* Maximum size is 50 characters.
* Required

## Goliath Events Origin

These Goliath Events were generated for the game **`8ballpool_mobile`**, id **704**. The Schema version that matches this SDK is **4.8.0**, and the server response version is **1**. Please make sure with the B.I. team that you’re using the appropriate versions to your current configuration.